@@ -646,21 +646,12 @@ OpenSSLAdapter::SSLPostConnectionCheck(SSL* ssl, const char* host) {
         break;
 
       void* ext_str = NULL;
-#if OPENSSL_VERSION_NUMBER >= 0x0090801fL
       if (meth->it) {
-        ext_str = ASN1_item_d2i(NULL, (const unsigned char**) &(extension->value->data), extension->value->length,
+        ext_str = ASN1_item_d2i(NULL, (const unsigned char **) &(extension->value->data), extension->value->length,
                                 ASN1_ITEM_ptr(meth->it));
       } else {
-        ext_str = meth->d2i(NULL, (const unsigned char**) &(extension->value->data), extension->value->length);
+        ext_str = meth->d2i(NULL, (const unsigned char **) &(extension->value->data), extension->value->length);
       }
-#else
-      if (meth->it) {
-        ext_str = ASN1_item_d2i(NULL, (unsigned char**) &(extension->value->data), extension->value->length,
-                                ASN1_ITEM_ptr(meth->it));
-      } else {
-        ext_str = meth->d2i(NULL, (unsigned char**) &(extension->value->data), extension->value->length);
-      }
-#endif
 
       STACK_OF(CONF_VALUE)* value = meth->i2v(meth, ext_str, NULL);
       for (int j = 0; j < sk_CONF_VALUE_num(value); ++j) {
@@ -781,11 +772,7 @@ OpenSSLAdapter::SetupSSLContext() {
   unsigned char* cert_buffer
     = EquifaxSecureGlobalEBusinessCA1_certificate;
   size_t cert_buffer_len = sizeof(EquifaxSecureGlobalEBusinessCA1_certificate);
-#if OPENSSL_VERSION_NUMBER >= 0x0090801fL
-  X509* cert = d2i_X509(NULL, (const unsigned char**) &cert_buffer, cert_buffer_len);
-#else
-  X509* cert = d2i_X509(NULL, (unsigned char**) &cert_buffer, cert_buffer_len);
-#endif
+  X509* cert = d2i_X509(NULL, (const unsigned char **) &cert_buffer, cert_buffer_len);
   if (cert == NULL) {
     SSL_CTX_free(ctx);
     return NULL;
