@@ -30,13 +30,20 @@
 #endif
 
 #include <cassert>
+#include <algorithm>
 
 #ifdef POSIX
 extern "C" {
+#include <stdio.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <time.h>
 #include <sys/time.h>
 #include <unistd.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netinet/ip.h>
+#include <string.h>
 }
 #endif
 
@@ -133,8 +140,20 @@ public:
     Close();
     s_ = ::socket(AF_INET, type, 0);
     UpdateLastError();
-    if (type != SOCK_STREAM)
-      enabled_events_ = kfRead | kfWrite;
+    int flag = IPTOS_LOWDELAY;
+    //int flag = (IPTOS_LOWDELAY|IPTOS_PREC_IMMEDIATE);
+    if (::setsockopt(s_, IPPROTO_IP, IP_TOS, &flag, sizeof(flag)) < 0)
+    {
+      perror("::setsockopt(,IPPROTO_IP,IP_TOS,IPTOS_LOWDELAY,)");
+      //perror("::setsockopt(,IPPROTO_IP,IP_TOS,(IPTOS_LOWDELAY|IPTOS_PREC_IMMEDIATE),)");
+    }
+    // FIXME: use SOPRIO_CONVERSATIONAL instead of numeric value
+    int prio = 6;
+    if (::setsockopt(s_, SOL_SOCKET, SO_PRIORITY, &prio, sizeof(prio)) < 0)
+    {
+      perror("::setsockopt(,SOL_SOCKET, SO_PRIORITY,)");
+    }
+    enabled_events_ = kfRead | kfWrite;
     return s_ != INVALID_SOCKET;
   }
 
@@ -835,7 +854,7 @@ bool PhysicalSocketServer::Wait(int cmsWait, bool process_io) {
 
   struct timeval *ptvWait = NULL;
   struct timeval tvWait;
-  struct timeval tvStop;
+  struct timespec tvStop;
   if (cmsWait != -1) {
     // Calculate wait timeval
     tvWait.tv_sec = cmsWait / 1000;
@@ -843,11 +862,11 @@ bool PhysicalSocketServer::Wait(int cmsWait, bool process_io) {
     ptvWait = &tvWait;
 
     // Calculate when to return in a timeval
-    gettimeofday(&tvStop, NULL);
+    clock_gettime(CLOCK_MONOTONIC, &tvStop);
     tvStop.tv_sec += tvWait.tv_sec;
-    tvStop.tv_usec += tvWait.tv_usec;
-    if (tvStop.tv_usec >= 1000000) {
-      tvStop.tv_usec -= 1000000;
+    tvStop.tv_nsec += tvWait.tv_usec * 1000;
+    if (tvStop.tv_nsec >= 1000000000) {
+      tvStop.tv_nsec -= 1000000000;
       tvStop.tv_sec += 1;
     }
   }
@@ -874,6 +893,8 @@ bool PhysicalSocketServer::Wait(int cmsWait, bool process_io) {
         if (!process_io && (pdispatcher != signal_wakeup_))
           continue;
         int fd = pdispatcher->GetDescriptor();
+        if (fd == INVALID_SOCKET)
+          continue;
         if (fd > fdmax)
           fdmax = fd;
         uint32 ff = pdispatcher->GetRequestedEvents();
@@ -908,6 +929,8 @@ bool PhysicalSocketServer::Wait(int cmsWait, bool process_io) {
       for (unsigned i = 0; i < dispatchers_.size(); i++) {
         Dispatcher *pdispatcher = dispatchers_[i];
         int fd = pdispatcher->GetDescriptor();
+        if (fd == INVALID_SOCKET)
+          continue;
         uint32 ff = 0;
         if (FD_ISSET(fd, &fdsRead)) {
           FD_CLR(fd, &fdsRead);
@@ -934,11 +957,11 @@ bool PhysicalSocketServer::Wait(int cmsWait, bool process_io) {
     if (cmsWait != -1) {
       ptvWait->tv_sec = 0;
       ptvWait->tv_usec = 0;
-      struct timeval tvT;
-      gettimeofday(&tvT, NULL);
+      struct timespec tvT;
+      clock_gettime(CLOCK_MONOTONIC, &tvT);
       if (tvStop.tv_sec >= tvT.tv_sec) {
         ptvWait->tv_sec = tvStop.tv_sec - tvT.tv_sec;
-        ptvWait->tv_usec = tvStop.tv_usec - tvT.tv_usec;
+        ptvWait->tv_usec = (tvStop.tv_nsec - tvT.tv_nsec)/1000;
         if (ptvWait->tv_usec < 0) {
           ptvWait->tv_usec += 1000000;
           ptvWait->tv_sec -= 1;
