@@ -33,6 +33,8 @@
 #include "talk/base/socket.h"
 #include "talk/base/time.h"
 #include "talk/p2p/base/pseudotcp.h"
+#include <stdlib.h>
+#include <string.h>
 
 #define _DBG_NONE		  0
 #define _DBG_NORMAL		1
