@@ -203,7 +203,7 @@ void RelayPort::SetReady() {
 }
 
 const ProtocolAddress * RelayPort::ServerAddress(size_t index) const {
-  if ((index >= 0) && (index < server_addr_.size()))
+  if (index < server_addr_.size())
     return &server_addr_[index];
   return 0;
 }
